@@ -10,7 +10,7 @@ import random
 import time
 
 import robot
-from SeleniumLibrary import LibraryComponent, JavaScriptKeywords, SelectElementKeywords
+from SeleniumLibrary import LibraryComponent, JavaScriptKeywords, SelectElementKeywords, SeleniumLibrary
 from SeleniumLibrary.errors import ElementNotFound
 from SeleniumLibrary.utils import is_noney
 from dateutil.relativedelta import relativedelta
@@ -671,7 +671,7 @@ class FacileToolkit2:
     @keyword
     def close_symfony_toolbar(self):
         self.set_selenium_library()
-        if BuiltIn().run_keyword_and_return_status("wait_until_element_is_visible", "body > .sf-toolbar"):
+        if BuiltIn().run_keyword_and_return_status("wait_until_element_is_visible", "css:body > .sf-toolbar"):
             self.sl.execute_javascript("document.querySelector('body > .sf-toolbar').style='display:none'")
 
     @keyword
